@@ -17,7 +17,7 @@ class CurveUtils:
         for i in range(0, 4):
             try:
                 t = self.curve_pool.coins(i)
-                tokens.append(EulithERC20(self.w3, self.w3.toChecksumAddress(t)))
+                tokens.append(EulithERC20(self.w3, self.w3.to_checksum_address(t)))
             except web3.exceptions.ContractLogicError:
                 break
 
@@ -39,7 +39,7 @@ class CurveUtils:
             dollar_denominated_balance = bal_float * price
             total_usd_value += dollar_denominated_balance
 
-        lp_token = EulithERC20(self.w3, self.w3.toChecksumAddress(self.curve_pool.token()))
+        lp_token = EulithERC20(self.w3, self.w3.to_checksum_address(self.curve_pool.token()))
         lp_supply = lp_token.total_supply() / 10 ** lp_token.decimals
 
         return total_usd_value / lp_supply
