@@ -40,6 +40,7 @@ class TokenSymbol(str, Enum):
     OSQTH = 'oSQTH'
     WSTETH = 'wstETH'
     ALBT = 'ALBT'
+    GLP = 'sGLP'
 
 
 class EulithERC20(IERCDetailed):
@@ -87,12 +88,10 @@ class EulithWETH(WETHInterface, EulithERC20):
     def deposit_wei(self, wei: int, override_tx_parameters: Optional[TxParams] = None) -> TxParams:
         tx = self.deposit(override_tx_parameters)
         tx['value'] = hex(wei)
-        tx['gas'] = 60000  # estimates are a little flaky here
         return tx
 
     # You must have sufficient WETH balance for this to succeed
     def withdraw_eth(self, whole_eth_as_float: float, override_tx_parameters: Optional[TxParams] = None) -> TxParams:
         wei = int(whole_eth_as_float * 1e18)
         tx = self.withdraw(wei, override_tx_parameters)
-        tx['gas'] = 60000  # estimates are a little flaky here
         return tx
