@@ -131,20 +131,15 @@ class LocalSigner(Signer):
         return self.private_key.sign_msg_hash(message_hash)
 
 
-def construct_signing_middleware(
-        account: Signer
-) -> Middleware:
-    """Capture transactions sign and send as raw transactions
-
-
-    Keyword arguments:
-    private_key_or_account -- A single private key or a tuple,
-    list or set of private keys. Keys can be any of the following formats:
-      - An eth_account.LocalAccount object
-      - An eth_keys.PrivateKey object
-      - A raw private key as a hex string or byte string
+def construct_signing_middleware(account: Signer) -> Middleware:
     """
+    Wrap signature source in middleware to allow for automatic signing when necessary for transactions
+    being signed and sent directly to the network (as opposed to an atomic transaction, which gets sent
+    unsigned to the Eulith server).
 
+    :param account: The LocalSigner, KMSSigner, or FireblocksSigner for your wallet
+    :type account: Signer
+    """
     acct = account
 
     def sign_and_send_raw_middleware(
