@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Optional, TypedDict
+from typing import Optional, TypedDict, Callable
 
 from eth_typing import ChecksumAddress
 
@@ -7,6 +7,7 @@ from eulith_web3.common import INT_FEE_TO_FLOAT_DIVISOR
 from eulith_web3.contract_bindings.i_uniswap_v3_pool import IUniswapV3Pool
 from eulith_web3.erc20 import EulithERC20
 from eulith_web3.exceptions import EulithRpcException
+from eulith_web3.websocket import SubscribeRequest, SubscriptionHandle
 
 
 class UniswapPoolFee(int, Enum):
@@ -51,9 +52,9 @@ class EulithUniswapPoolLookupRequest(TypedDict):
 class EulithUniswapV3Pool(IUniswapV3Pool):
     def __init__(self, eulith_web3,
                  pool_address: ChecksumAddress,
-                 fee: Optional[UniswapPoolFee],
-                 token0: Optional[ChecksumAddress],
-                 token1: Optional[ChecksumAddress]):
+                 fee: Optional[UniswapPoolFee] = None,
+                 token0: Optional[ChecksumAddress] = None,
+                 token1: Optional[ChecksumAddress] = None):
         super().__init__(eulith_web3, pool_address)
         self.pool_fee = fee
         self.t0 = token0
@@ -62,14 +63,14 @@ class EulithUniswapV3Pool(IUniswapV3Pool):
 
     def get_token_zero(self) -> EulithERC20:
         if not self.t0:
-            self.t0 = self.ew3.toChecksumAddress(self.token0())
+            self.t0 = self.ew3.to_checksum_address(self.token0())
             return EulithERC20(self.ew3, self.t0)
         else:
             return EulithERC20(self.ew3, self.t0)
 
     def get_token_one(self) -> EulithERC20:
         if not self.t1:
-            self.t1 = self.ew3.toChecksumAddress(self.token1())
+            self.t1 = self.ew3.to_checksum_address(self.token1())
             return EulithERC20(self.ew3, self.t1)
         else:
             return EulithERC20(self.ew3, self.t1)
@@ -107,7 +108,21 @@ class EulithUniswapV3Pool(IUniswapV3Pool):
         status, res = self.ew3.eulith_data.uniswap_v3_quote(params)
 
         if status:
-            price, fee, swap_request = self.ew3.parse_uni_quote_to_swap_request(res, fill_or_kill, recipient, pay_transfer_from)
+            price, fee, swap_request = self.ew3.parse_uni_quote_to_swap_request(res, fill_or_kill, recipient,
+                                                                                pay_transfer_from)
             return price, fee / INT_FEE_TO_FLOAT_DIVISOR, swap_request
         else:
             raise EulithRpcException(res)
+
+    def subscribe_prices(self, message_handler: Callable, error_handler: Callable) -> SubscriptionHandle:
+        subscribe_request = SubscribeRequest(
+            subscription_type='uni_prices',
+            args={
+                'pool_address': self.address
+            }
+        )
+
+        return self.ew3.websocket_conn.subscribe(
+            subscribe_request=subscribe_request,
+            message_handler=message_handler,
+            error_handler=error_handler)
